==> redis-7.x-3.4.tar.gz: redis/lib/Redis/Tests/Cache/FixesUnitTestCase.php <==
<?php

/**
 * Bugfixes made over time test class.
 */
abstract class Redis_Tests_Cache_FixesUnitTestCase extends Redis_Tests_AbstractUnitTestCase
{
    /**
     * Get cache backend
     *
     * @return Redis_Cache
     */
    final protected function getBackend()
    {
        return new Redis_Cache('cache');
    }

    public function testTemporaryCacheExpire()
    {
        global $conf; // We are in unit tests so variable table does not exist.

        $backend = $this->getBackend();

        // Permanent entry.
        $backend->set('test1', 'foo', CACHE_PERMANENT);
        $data = $backend->get('test1');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('foo', $data->data);

        // Permanent entries should not be dropped on clear() call.
        $backend->clear();
        $data = $backend->get('test1');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('foo', $data->data);

        // Expiring entry with permanent default lifetime.
        $conf['cache_lifetime'] = 0;
        $backend->set('test2', 'bar', CACHE_TEMPORARY);
        sleep(2);
        $data = $backend->get('test2');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('bar', $data->data);
        sleep(2);
        $data = $backend->get('test2');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('bar', $data->data);

        // Expiring entry with negative lifetime.
        $backend->set('test3', 'baz', time() - 100);
        $data = $backend->get('test3');
        $this->assertEqual(false, $data);

        // Expiring entry with short lifetime.
        $backend->set('test4', 'foobar', time() + 2);
        $data = $backend->get('test4');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('foobar', $data->data);
        sleep(4);
        $data = $backend->get('test4');
        $this->assertEqual(false, $data);

        // Expiring entry with short default lifetime.
        $conf['cache_lifetime'] = 1;
        $backend->refreshMaxTtl();
        $backend->set('test5', 'foobaz', CACHE_TEMPORARY);
        $data = $backend->get('test5');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('foobaz', $data->data);
        sleep(3);
        $data = $backend->get('test5');
        $this->assertEqual(false, $data);
    }

    public function testDefaultPermTtl()
    {
        $backend = $this->getBackend();
        $this->assertIdentical(Redis_Cache::LIFETIME_PERM_DEFAULT, $backend->getPermTtl());
    }

    public function testUserSetDefaultPermTtl()
    {
        global $conf;
        // This also testes string parsing. Not fully, but at least one case.
        $conf['redis_perm_ttl'] = "3 months";
        $backend = $this->getBackend();
        $this->assertIdentical(7776000, $backend->getPermTtl());
    }

    public function testUserSetPermTtl()
    {
        global $conf;
        // This also testes string parsing. Not fully, but at least one case.
        $conf['redis_perm_ttl_cache'] = "1 months";
        $backend = $this->getBackend();
        $this->assertIdentical(2592000, $backend->getPermTtl());
    }

    public function testPermTtl()
    {
        global $conf;
        // This also testes string parsing. Not fully, but at least one case.
        $conf['redis_perm_ttl_cache'] = "2 seconds";
        $backend = $this->getBackend();
        $this->assertIdentical(2, $backend->getPermTtl());

        $backend->set('test6', 'cats are mean');
        $this->assertIdentical('cats are mean', $backend->get('test6')->data);

        sleep(3);
        $item = $backend->get('test6');
        $this->assertTrue(empty($item));
    }

    public function testClearAsArray()
    {
        $backend = $this->getBackend();

        $backend->set('test7', 1);
        $backend->set('test8', 2);
        $backend->set('test9', 3);

        $backend->clear(array('test7', 'test9'));

        $item = $backend->get('test7');
        $this->assertTrue(empty($item));
        $item = $backend->get('test8');
        $this->assertEqual(2, $item->data);
        $item = $backend->get('test9');
        $this->assertTrue(empty($item));
    }

    public function testGetMultipleAlterCidsWhenCacheHitsOnly()
    {
        $backend = $this->getBackend();

        $backend->set('test8', 1);
        $backend->clear('test9');

        $cids_partial_hit = array('test8', 'test9');
        $backend->getMultiple($cids_partial_hit);
        // Note that the 1 key is important because the method should
        // keep the keys synchronized.
        $this->assertEqual(array(1 => 'test9'), $cids_partial_hit);

        $backend->clear('test8');

        $cids_no_hit = array('test8', 'test9');
        $backend->getMultiple($cids_no_hit);
        $this->assertEqual(array('test8', 'test9'), $cids_no_hit);
    }
}

==> redis-7.x-3.5.tar.gz: redis/lib/Redis/Tests/Cache/FixesUnitTestCase.php <==
<?php

/**
 * Bugfixes made over time test class.
 */
abstract class Redis_Tests_Cache_FixesUnitTestCase extends Redis_Tests_AbstractUnitTestCase
{
    /**
     * @var Cache bin identifier
     */
    static private $id = 1;

    /**
     * Get cache backend
     *
     * @return Redis_Cache
     */
    final protected function getBackend($name = null)
    {
        if (null === $name) {
            // This is needed to avoid conflict between tests, each test
            // seems to use the same Redis namespace and conflicts are
            // possible.
            $name = 'cache' . (self::$id++);
        }
        return new Redis_Cache($name);
    }

    public function testTemporaryCacheExpire()
    {
        global $conf; // We are in unit tests so variable table does not exist.

        $backend = $this->getBackend();

        // Permanent entry.
        $backend->set('test1', 'foo', CACHE_PERMANENT);
        $data = $backend->get('test1');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('foo', $data->data);

        // Permanent entries should not be dropped on clear() call.
        $backend->clear();
        $data = $backend->get('test1');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('foo', $data->data);

        // Expiring entry with permanent default lifetime.
        $conf['cache_lifetime'] = 0;
        $backend->set('test2', 'bar', CACHE_TEMPORARY);
        sleep(2);
        $data = $backend->get('test2');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('bar', $data->data);
        sleep(2);
        $data = $backend->get('test2');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('bar', $data->data);

        // Expiring entry with negative lifetime.
        $backend->set('test3', 'baz', time() - 100);
        $data = $backend->get('test3');
        $this->assertEqual(false, $data);

        // Expiring entry with short lifetime.
        $backend->set('test4', 'foobar', time() + 2);
        $data = $backend->get('test4');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('foobar', $data->data);
        sleep(4);
        $data = $backend->get('test4');
        $this->assertEqual(false, $data);

        // Expiring entry with short default lifetime.
        $conf['cache_lifetime'] = 1;
        $backend->refreshMaxTtl();
        $backend->set('test5', 'foobaz', CACHE_TEMPORARY);
        $data = $backend->get('test5');
        $this->assertNotEqual(false, $data);
        $this->assertIdentical('foobaz', $data->data);
        sleep(3);
        $data = $backend->get('test5');
        $this->assertEqual(false, $data);
    }

    public function testDefaultPermTtl()
    {
        global $conf;
        unset($conf['redis_perm_ttl']);
        $backend = $this->getBackend();
        $this->assertIdentical(Redis_Cache::LIFETIME_PERM_DEFAULT, $backend->getPermTtl());
    }

    public function testUserSetDefaultPermTtl()
    {
        global $conf;
        // This also testes string parsing. Not fully, but at least one case.
        $conf['redis_perm_ttl'] = "3 months";
        $backend = $this->getBackend();
        $this->assertIdentical(7776000, $backend->getPermTtl());
    }

    public function testUserSetPermTtl()
    {
        global $conf;
        // This also testes string parsing. Not fully, but at least one case.
        $conf['redis_perm_ttl'] = "1 months";
        $backend = $this->getBackend();
        $this->assertIdentical(2592000, $backend->getPermTtl());
    }

    public function testPermTtl()
    {
        global $conf;
        // This also testes string parsing. Not fully, but at least one case.
        $conf['redis_perm_ttl'] = "2 seconds";
        $backend = $this->getBackend();
        $this->assertIdentical(2, $backend->getPermTtl());

        $backend->set('test6', 'cats are mean');
        $this->assertIdentical('cats are mean', $backend->get('test6')->data);

        sleep(3);
        $item = $backend->get('test6');
        $this->assertTrue(empty($item));
    }

    public function testClearAsArray()
    {
        $backend = $this->getBackend();

        $backend->set('test7', 1);
        $backend->set('test8', 2);
        $backend->set('test9', 3);

        $backend->clear(array('test7', 'test9'));

        $item = $backend->get('test7');
        $this->assertTrue(empty($item));
        $item = $backend->get('test8');
        $this->assertEqual(2, $item->data);
        $item = $backend->get('test9');
        $this->assertTrue(empty($item));
    }

    public function testGetMultipleAlterCidsWhenCacheHitsOnly()
    {
        $backend = $this->getBackend();

        $backend->set('test8', 1);
        $backend->clear('test9');

        $cids_partial_hit = array('test8', 'test9');
        $backend->getMultiple($cids_partial_hit);
        // Note that the 1 key is important because the method should
        // keep the keys synchronized.
        $this->assertEqual(array(1 => 'test9'), $cids_partial_hit);

        $backend->clear('test8');

        $cids_no_hit = array('test8', 'test9');
        $backend->getMultiple($cids_no_hit);
        $this->assertEqual(array('test8', 'test9'), $cids_no_hit);
    }
}
